#
# spec file for package python-sqlitedict
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-sqlitedict
Version:        2.1.0
Release:        1.3
Summary:        Persistent dict in Python backed by sqlite3
License:        Apache-2.0
URL:            https://github.com/piskvorky/sqlitedict
Source:         https://files.pythonhosted.org/packages/source/s/sqlitedict/sqlitedict-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  %{pythons}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python
BuildArch:      noarch
%python_subpackages

%description
A wrapper around Python's sqlite3 database with a Pythonic
dict-like interface and support for multi-thread access.

%prep
%setup -q -n sqlitedict-%{version}
sed -i -e '/^#!\//, 1d' sqlitedict.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
%{python_expand # db needs to be regenerated
rm -rf tests/db
mkdir -p tests/db
PYTHONPATH=%{buildroot}%{$python_sitelib} pytest-%{$python_bin_suffix}
}

%files %{python_files}
%license LICENSE.md
%doc README.rst
%{python_sitelib}/sqlitedict.py
%pycache_only %{python_sitelib}/__pycache__/sqlitedict.*.py*
%{python_sitelib}/sqlitedict-%{version}.dist-info

%changelog
* Fri Mar 15 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to 2.1.0:
  * Fix setDaemon deprecated warning
  * adding optional ability to encode keys
  * Change logging from info to debug
  * Properly handle the race condition
  * Correct spelling mistakes
  * Introduce weak references
  * This release supports Python 3.7 and above
  * Do not create tables when in read-only mode
  * Use tempfile.mkstemp for safer temp file creation
  * Fix deadlock where opening database fails
  * Make outer_stack a parameter
  * Add a blocking commit after each modification if autocommit is enabled
  * Clean up license file names
  * support double quotes in table names
- Switch to pyproject macros.
- No more greedy globs in %%files.
* Wed Jun  3 2020 Marketa Calabkova <mcalabkova@suse.com>
- replace nose with pytest
* Wed Dec 11 2019 Tomáš Chvátal <tchvatal@suse.com>
- Depend on full python stack for sqlite
* Wed Apr 10 2019 pgajdos@suse.com
- version update to 1.6.0
  * Add `get_tablenames` method (@transfluxus, #72)
  * Add license files to dist (@toddrme2178, #79)
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Sun Jul 29 2018 jengelh@inai.de
- Ensure neutrality of descriptions.
* Thu May 24 2018 toddrme2178@gmail.com
- rpmlint fixes
* Wed May 24 2017 toddrme2178@gmail.com
- Initial version
